@@ -55,7 +55,7 @@ log = logging.getLogger(__name__)
 
 
 class Client(object):
-    __version__ = '0.4'
+    __version__ = '0.4.1'
     __protocol_version__ = '0.3'
 
     def __init__(self, config):
@@ -65,10 +65,9 @@ class Client(object):
             errormator = true
             errormator.server_url = https://api.errormator.com
             errormator.api_key = YOUR_API_KEY
-            errormator.report_404 = true
-        
+
         additional config keys you can set in config object::
-        
+
             errormator.server_name - identifier for Instance/Server Name your application is running on (default: auto determined fqdn of server)
             errormator.timeout - connection timeout when communicating with API
             errormator.reraise_exceptions - reraise exceptions when wsgi catches exception
@@ -76,7 +75,6 @@ class Client(object):
             errormator.logging - enable hooking to application loggers
             errormator.logging.level - minimum log level for log capture
             errormator.logging_on_error - send logs only from erroneous/slow requests (default false) 
-            errormator.datastores - enable query execution tracking for various datastore layers
             errormator.slow_request_time - (float/int) time in seconds after request is considered being slow (default 3)
             errormator.report_404 - enables 404 error logging (default False)
             errormator.report_errors - enables 500 error logging (default True)
@@ -88,7 +86,7 @@ class Client(object):
             (by default client will always blank keys that contain following words 'password', 'passwd', 'pwd', 'auth_tkt', 'secret', 'csrf', this list be extended with additional keywords set in config)
             errormator.log_namespace_blacklist - list of namespaces that should be ignores when gathering log entries, can be string with comma separated list of namespaces
             (by default the client ignores own entries: errormator_client.client)
-            
+
         """
         self.config = {}
         # general options
@@ -96,35 +94,32 @@ class Client(object):
         self.config['server_name'] = config.get('errormator.server_name') or socket.getfqdn()
         self.config['client'] = config.get('errormator.client', 'python')
         self.config['api_key'] = config.get('errormator.api_key')
-        self.config['server_url'] = config.get('errormator.server_url')
+        self.config['server_url'] = config.get('errormator.server_url', 'https://api.errormator.com')
         self.config['timeout'] = int(config.get('errormator.timeout', 10))
         self.config['reraise_exceptions'] = asbool(
                 config.get('errormator.reraise_exceptions', True))
         self.config['slow_requests'] = asbool(config.get('errormator.slow_requests', True))
         self.config['slow_request_time'] = float(config.get('errormator.slow_request.time', 3))
-        self.config['slow_query_time'] = float(config.get('errormator.slow_query.time', 1))
-        if self.config['slow_request_time'] < 0.1:
-            self.config['slow_request_time'] = 0.1
-        if self.config['slow_query_time'] < 0.1:
-            self.config['slow_query_time'] = 0.1
+        if self.config['slow_request_time'] < 0.01:
+            self.config['slow_request_time'] = 0.01
         self.config['slow_request_time'] = datetime.timedelta(seconds=self.config['slow_request_time'])
-        self.config['slow_query_time'] = datetime.timedelta(seconds=self.config['slow_query_time'])
         self.config['logging'] = asbool(config.get('errormator.logging', True))
         self.config['logging_on_error'] = asbool(config.get('errormator.logging_on_error', False))
-        self.config['datastores'] = asbool(config.get('errormator.datastores', True))
         self.config['report_404'] = asbool(config.get('errormator.report_404', False))
         self.config['report_errors'] = asbool(config.get('errormator.report_errors', True))
         self.config['buffer_flush_interval'] = int(config.get('errormator.buffer_flush_interval', 5))
         self.config['force_send'] = asbool(config.get('errormator.force_send', False))
-        self.config['request_keys_blacklist'] = ['password', 'passwd', 'pwd', 'auth_tkt', 'secret', 'csrf']
+        self.config['request_keys_blacklist'] = ['password', 'passwd', 'pwd', 'auth_tkt', 'secret', 'csrf',
+                                                 'session']
         user_blacklist = aslist(config.get('errormator.request_keys_blacklist',
                                            config.get('errormator.bad_request_keys')), ',')
         self.config['request_keys_blacklist'].extend(user_blacklist)
         if config.get('errormator.bad_request_keys'):
-            log.warning('errormator.bad_request_keys is deprecated use request_keys_blacklist')
+            log.warning('errormator.bad_request_keys is deprecated use request_keys_blacklist') #pragma: nocover
 
         self.config['environ_keys_whitelist'] = [
-                'REMOTE_USER', 'REMOTE_ADDR', 'SERVER_NAME', 'CONTENT_TYPE']
+                'REMOTE_USER', 'REMOTE_ADDR', 'SERVER_NAME', 'CONTENT_TYPE',
+                'HTTP_REFERER']
         environ_whitelist = aslist(config.get('errormator.environ_keys_whitelist'), ',')
         self.config['environ_keys_whitelist'].extend(environ_whitelist)
         self.config['log_namespace_blacklist'] = aslist(config.get('errormator.log_namespace_blacklist', 'errormator_client.client'), ',')
@@ -143,12 +138,14 @@ class Client(object):
 
         if self.config['buffer_flush_interval'] < 1:
             self.config['buffer_flush_interval'] = 1
+        self.config['buffer_flush_interval'] = datetime.timedelta(
+                            seconds=self.config['buffer_flush_interval'])
         # register logging
         import errormator_client.logger
         if self.config['logging']:
             self.log_handler = errormator_client.logger.register_logging()
             level = LEVELS.get(config.get('errormator.logging.level',
-                                      'NOTSET').lower(), logging.NOTSET)
+                                      'WARNING').lower(), logging.WARNING)
             self.log_handler.setLevel(level)
 
         # register slow call metrics
@@ -162,7 +159,6 @@ class Client(object):
                         self.config['timing'][k[18:]] = False
             import errormator_client.timing
             errormator_client.timing.register_timing(self.config)
-            self.datastore_handler = errormator_client.logger.register_datastores()
 
         self.endpoints = {
                           "reports": '/api/reports',
@@ -191,7 +187,9 @@ class Client(object):
                     raise KeyboardInterrupt()
                 except Exception as e:
                     log.warning('REPORTS: connection issue: %s' % e)
-        send()
+                    return False
+            return True
+        return send()
         # FIXME: reintroduce threads
 
     def submit_other_data(self):
@@ -219,17 +217,20 @@ class Client(object):
                     raise KeyboardInterrupt()
                 except Exception as e:
                     log.warning('LOGS: connection issue: %s' % e)
-        send()
+            return True
+        return send()
         # FIXME: reintroduce threads
 
     def check_if_deliver(self, force_send=False):
         delta = datetime.datetime.now() - self.last_submit
-        if delta.seconds > self.config['buffer_flush_interval'] or force_send:
+        if delta > self.config['buffer_flush_interval'] or force_send:
             submit_report_data_t = threading.Thread(target=self.submit_report_data)
             submit_report_data_t.start()
             submit_other_data_t = threading.Thread(target=self.submit_other_data)
             submit_other_data_t.start()
             self.last_submit = datetime.datetime.now()
+            return True
+        return False
 
     def remote_call(self, data, endpoint):
         GET_vars = urllib.urlencode({'protocol_version': self.__protocol_version__})
@@ -325,9 +326,6 @@ class Client(object):
                     server=self.config['server_name'], include_params=True)
         report_data = self.filter_callable(report_data, 'slow_report')
         url = report_data['report_details'][0]['url']
-        if not records:
-            records = self.datastore_handler.get_records()
-            self.datastore_handler.clear_records()
         report_data['report_details'][0]['start_time'] = start_time
         report_data['report_details'][0]['end_time'] = end_time
         report_data['report_details'][0]['slow_calls'] = []
@@ -382,7 +380,10 @@ class Client(object):
             remote_addr = (environ.get("HTTP_X_REAL_IP")
                            or environ.get('REMOTE_ADDR'))
         parsed_environ['REMOTE_ADDR'] = remote_addr
-        errormator_info['URL'] = req.url
+        try:
+            errormator_info['URL'] = req.url
+        except (UnicodeEncodeError, UnicodeDecodeError), e:
+            errormator_info['URL'] = '/invalid-encoded-url'
         return parsed_environ, errormator_info
 
 
@@ -391,6 +392,7 @@ class Client(object):
         (parsed_environ, errormator_info) = self.process_environ(environ, traceback,
                                                             include_params)
         report_data = {'client': 'Python', 'report_details': []}
+        report_data['error_type'] = 'Unknown'
         if traceback:
             exception_text = traceback.exception
             traceback_text = traceback.plaintext
